@@ -638,15 +638,16 @@ static int cuecat_read_proc(char *page,
 {
   int len=0, i;
   off_t begin=0;
+  int first_info=1;
 
   for(i=0;i<MAX_CUECAT_SOURCES;i++)
   {
     if(driver_info[i].driver_present)
     {
-      if(i<MAX_CUECAT_SOURCES-1)
-        len+=sprintf(page+len,"CC%d=%d,",i,driver_info[i].driver_enabled);
-      else
-        len+=sprintf(page+len,"CC%d=%d\n",i,driver_info[i].driver_enabled);
+      if(!first_info)
+        len+=sprintf(page+len,",");
+      first_info=0;
+      len+=sprintf(page+len,"CC%d=%d",i,driver_info[i].driver_enabled);
     }
 
     /* If we've written more than requested, quit */
@@ -661,6 +662,16 @@ static int cuecat_read_proc(char *page,
     }
   }
 
+  /* Add the final newline */
+  len+=sprintf(page+len,"\n");
+
+  /* If the process requested to start after this point, don't bother saving*/
+  if(len+begin<offset)
+  {
+    begin+=len;
+    len=0;
+  }
+
   /* If we reached the end, set EOF */
   if(i>=MAX_CUECAT_SOURCES)
     *eof=1;
